local math2d = require("__core__/lualib/math2d")

local kWallLength = 42 / 64
local kCarLength = 2
local kMaxGap = 5

--- @param player LuaPlayer
--- @param vehicle LuaEntity
local function try_place_wall(player, vehicle)
  if (vehicle.speed < 0.1) then
    return
  end

  local car_end = math2d.position.subtract(vehicle.position,
    math2d.vector.from_orientation(vehicle.orientation, kCarLength))

  local last_placed_wall = storage.last_placed_wall
  if (not last_placed_wall or
        math2d.position.distance(car_end, last_placed_wall) > kMaxGap) then
    local wall = vehicle.surface.create_entity({
      name = "tron-wall",
      position = math2d.position.subtract(
        car_end,
        math2d.vector.projected(
          math2d.vector.from_orientation(vehicle.orientation, kWallLength / 2))),
      snap_to_grid = false,
      player_index = player.index,
      force = player.force,
    })
    wall.graphics_variation = (math.floor(vehicle.orientation * 64) + 16) % 64 + 1

    storage.last_placed_wall = car_end
    return
  end

  while (math2d.position.distance(last_placed_wall, car_end) > kWallLength) do
    local direction_to_car = math2d.position.subtract(car_end, last_placed_wall)
    local wall_orientation = math2d.vector.to_orientation(
      { x = direction_to_car.x, y = direction_to_car.y / math2d.projection_constant })
    local wall = vehicle.surface.create_entity({
      name = "tron-wall",
      position = math2d.position.add(
        last_placed_wall,
        math2d.vector.projected(
          math2d.vector.from_orientation(wall_orientation, kWallLength / 2))),
      snap_to_grid = false,
      player_index = 1,
      force = "player",
    })
    wall.graphics_variation = (math.floor(wall_orientation * 64) + 16) % 64 + 1
    last_placed_wall = math2d.position.add(last_placed_wall, math2d.vector.projected(
      math2d.vector.from_orientation(wall_orientation, kWallLength)))
  end
  storage.last_placed_wall = last_placed_wall
end

--- @param event EventData.on_tick
local function on_tick(event)
  for _, player in pairs(game.players) do
    local vehicle = player.physical_vehicle
    if (vehicle and vehicle.name == "tron-lightcycle") then
      try_place_wall(player, vehicle)
    end
  end
end

script.on_event(defines.events.on_tick, on_tick)
