local path = ('__TronLegacy-LightCycle__')
local hit_effects = require ("__base__/prototypes/entity/hit-effects")
local sounds = require("__base__/prototypes/entity/sounds.lua")
local movement_triggers = require("__base__.prototypes.entity.movement-triggers")
local remnantsequence = {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}

local lightcyclehealth = settings.startup["tron-lightcyclehp"].value


local highfreqengine = {
  sound =
  {
    filename = path .. "/sounds/engine.ogg",
    volume = 0.8,
  },
  activate_sound =
  {
    filename = path .. "/sounds/start.ogg",
    volume = 2,
  },
  deactivate_sound =
  {
    filename = path .. "/sounds/end.ogg",
    volume = 0.4
  },      
  match_speed_to_activity = true,
}

local lowfreqengine = {
  sound =
  {
    filename = path .. "/sounds/engine2.ogg",
    volume = 0.8,
  },
  activate_sound =
  {
    filename = path .. "/sounds/start.ogg",
    volume = 2,
  },
  deactivate_sound =
  {
    filename = path .. "/sounds/end.ogg",
    volume = 0.4
  },      
  match_speed_to_activity = true,
}

local remnants = {
  {
    type = "corpse",
    name = "tron-lightcycle-remnants",
    icon = path .. "/graphics/icons/tron128.png",
    icon_size = 128,
    flags = {"placeable-neutral", "building-direction-8-way", "not-on-map"},
    subgroup = "transport-remnants",
    order = "a-k-a",
    selection_box = {{-1.3, -1.3}, {1.3, 1.3}},
    tile_width = 3,
    tile_height = 5,
    selectable_in_game = false,
    dying_speed = 0.035,
    time_before_removed = 60 * 60 * 2, 
    final_render_layer = "remnants",
    remove_on_tile_placement = false,
    animation = {
      layers = {
        {
          filename = path .. '/graphics/entity/legacycycle/hr-troncyclerem.png',
          line_length = 1,
          animation_speed = 1,
          width = 440,
          height = 360,
          frame_count = 1,
          repeat_count = #remnantsequence,
          direction_count = 4,
          shift = util.by_pixel(0, 0),
          scale = 0.5
        },        
        {
          filename = path .. '/graphics/entity/legacycycle/hr-troncycleremmsk.png',
          line_length = 1,
          animation_speed = 1,
          width = 440,
          height = 360,
          frame_count = 1,
          repeat_count = #remnantsequence,
          direction_count = 4,
          shift = util.by_pixel(0, 0),
          apply_runtime_tint = true,
          scale = 0.5
        },
        {
          filename = path .. '/graphics/entity/legacycycle/hr-troncycleremglo.png',
          line_length = 8,
          width = 440,
          height = 360,
          frame_count = 16,
          frame_sequence = remnantsequence,
          direction_count = 4,
          shift = util.by_pixel(0, 0),
          draw_as_glow = true,
          apply_runtime_tint = true,
          scale = 0.5
        },
        {
          filename = path .. '/graphics/entity/legacycycle/hr-troncycleremglo.png',
          line_length = 8,
          blend_mode = "additive",
          width = 440,
          height = 360,
          frame_count = 16,
          frame_sequence = remnantsequence,
          direction_count = 4,
          shift = util.by_pixel(0, 0),
          draw_as_light = true,
          scale = 0.5
        }
      }
    }
  },
}

data:extend(remnants)


data:extend({
  -----LegacyCycle-----
  {
    type = "car",
    name = "tron-lightcycle",
    icon = path .. "/graphics/icons/tron64.png",
    icon_size = 64, icon_mipmaps = 4,
    flags = {"placeable-neutral", "player-creation", "placeable-off-grid", "not-flammable"},
    minable = {mining_time = 0.3, result = "tron-lightcycle"},
    mined_sound = {filename = "__core__/sound/deconstruct-large.ogg",volume = 0.8},
    max_health = lightcyclehealth,
    corpse = "tron-lightcycle-remnants",
    dying_explosion = "car-explosion",
    alert_icon_shift = util.by_pixel(0, -13),
    trash_inventory_size = 8,
    allow_remote_driving = true,
    energy_per_hit_point = 0.1,
    equipment_grid = "tron-lightcycle-equipment-grid",
    resistances =
    {
      {
        type = "fire",
        decrease = 10,
        percent = 40
      },
      {
        type = "physical",
        decrease = 10,
        percent = 40
      },
      {
        type = "impact",
        decrease = 30,
        percent = 75
      },
      {
        type = "explosion",
        decrease = 10,
        percent = 45
      },
      {
        type = "acid",
        decrease = 0,
        percent = 45
      }
    },
    collision_box = {{-0.7, -1.4}, {0.7, 1.7}},
    selection_box = {{-0.7, -1.4}, {0.7, 1.7}},
    damaged_trigger_effect = hit_effects.entity(),
    drawing_box = {{-0.8, -1}, {0.8, 1}},
    effectivity = 1,
    braking_power = "1000kW",
    energy_source =
    {
      type = "burner",
      fuel_categories = {"encom-cell"},
      effectivity = 1,
      fuel_inventory_size = 2,
      burnt_inventory_size = 2
    },
    consumption = "150kW",
    friction = 2e-3,
    light =
    {
      {
        type = "oriented",
        minimum_darkness = 0.3,
        picture =
        {
          filename = "__core__/graphics/light-cone.png",
          priority = "extra-high",
          flags = { "light" },
          scale = 2,
          width = 200,
          height = 200
        },
        shift = {0,-7},
        size = 1,
        intensity = 1,
        color = {r = 1.0, g = 1.0, b = 0.8},
        source_orientation_offset = 0
      }
    },
    light_animation =
    {
      priority = "low",
      blend_mode = "additive",
      draw_as_light = true,
      width = 512,
      height = 512,
      frame_count = 3,
      direction_count = 64,
      animation_speed = 8,
      shift = util.by_pixel(0, 15),
      stripes =
      {
        {
            filename = path .. '/graphics/entity/legacycycle/hr-legacycyclelight1.png',
            width_in_frames = 3,
            height_in_frames = 16
        },
        {
            filename = path .. '/graphics/entity/legacycycle/hr-legacycyclelight2.png',
            width_in_frames = 3,
            height_in_frames = 16
        },
        {
            filename = path .. '/graphics/entity/legacycycle/hr-legacycyclelight3.png',
            width_in_frames = 3,
            height_in_frames = 16
        },
        {
            filename = path .. '/graphics/entity/legacycycle/hr-legacycyclelight4.png',
            width_in_frames = 3,
            height_in_frames = 16
        }
      },
      scale = 0.5
    },
    animation =
    {
      layers =
      {
        {--Base layer--
          priority = "low",
          width = 306,
          height = 274,
          frame_count = 3,
          direction_count = 64,
          shift = util.by_pixel(0,-3),
          animation_speed = 3,
          max_advance = 1,
          stripes =
          {
            {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycycle1.png",
            width_in_frames = 3,
            height_in_frames = 16
            },
            {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycycle2.png",
            width_in_frames = 3,
            height_in_frames = 16
            },
            {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycycle3.png",
            width_in_frames = 3,
            height_in_frames = 16
            },
            {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycycle4.png",
            width_in_frames = 3,
            height_in_frames = 16
            }
          },
          scale = 0.5
        },
        {--mask layer--
          priority = "low",
          width = 400,
          height = 384,
          frame_count = 3,
          apply_runtime_tint = true,
          direction_count = 64,
          shift = util.by_pixel(0,0),
          max_advance = 1,
          line_length = 3,
          stripes = 
          {
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclemsk1.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclemsk2.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclemsk3.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclemsk4.png",
              width_in_frames = 3,
              height_in_frames = 16
            }             
          },
          scale = 0.5
        },
        --glow layer--
        {
          priority = "low",
          width = 512,
          height = 512,
          frame_count = 3,
          apply_runtime_tint = true,
          draw_as_glow = true,
          direction_count = 64,
          shift = util.by_pixel(0,15),
          max_advance = 1,
          line_length = 3,
          stripes = 
          {
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclelight1.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclelight2.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclelight3.png",
              width_in_frames = 3,
              height_in_frames = 16
            },
            {
              filename = path .. "/graphics/entity/legacycycle/hr-legacycyclelight4.png",
              width_in_frames = 3,
              height_in_frames = 16
            }             
          },
          scale = 0.5
        },
        {--shadow layer
          priority = "low",
          width = 370,
          height = 274,
          frame_count = 3,
          draw_as_shadow = true,
          direction_count = 64,
          shift = util.by_pixel(22,0),
          max_advance = 1,
          line_length = 3,
          stripes = 
          {
          {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycyclesh1.png",
            width_in_frames = 3,
            height_in_frames = 16
          },
          {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycyclesh2.png",
            width_in_frames = 3,
            height_in_frames = 16
          },
          {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycyclesh3.png",
            width_in_frames = 3,
            height_in_frames = 16
          },
          {
            filename = path .. "/graphics/entity/legacycycle/hr-legacycyclesh4.png",
            width_in_frames = 3,
            height_in_frames = 16
          }
          },
          scale = 0.5
        }
      }
    },
    turret_animation = {
      layers = {
        {
          filename = path .. "/graphics/entity/legacycycle/hr-legacycycleturret.png",
          priority = 'high',
          render_layer = 'higher-object-above',
          line_length = 8,
          width = 64,
          height = 64,
          frame_count = 1,
          direction_count = 64,
          shift = util.by_pixel(0, -30),
          animation_speed = 8,
          scale = 0.5
        },        
        {
          filename = path .. "/graphics/entity/legacycycle/hr-legacycycleturretmg.png",
          priority = 'low',
          render_layer = 'higher-object-under',
          line_length = 8,
          width = 40,
          height = 40,
          frame_count = 1,
          draw_as_glow = true,
          apply_runtime_tint = true,
          direction_count = 64,
          shift = util.by_pixel(0, -30),
          scale = 0.5
        },
        {
          filename = path .. "/graphics/entity/legacycycle/hr-legacycycleturretmg.png",
          priority = 'low',
          render_layer = 'higher-object-under',
          line_length = 8,
          width = 40,
          height = 40,
          frame_count = 1,
          apply_runtime_tint = true,
          direction_count = 64,
          shift = util.by_pixel(0, -30),
          scale = 0.5
        }
      }
    },
    turret_rotation_speed = 0.60 / 60,
    turret_return_timeout = 300,            
    sound_no_fuel =
    {
      {
        filename = "__base__/sound/fight/tank-no-fuel-1.ogg",
        volume = 0.4
      }
    },
    sound_minimum_speed = 0.1,
    sound_scaling_ratio = 1,
    vehicle_impact_sound = sounds.generic_impact,
    working_sound = settings.startup["engine-sound"].value and highfreqengine or lowfreqengine,
    stop_trigger_speed = 0.1,
    stop_trigger =
    {
      {
        type = "play-sound",
        sound =
        {
          {
            filename = "__base__/sound/fight/tank-brakes.ogg",
            volume = 0.3
          }
        }
      }
    },
    open_sound = { filename = "__base__/sound/fight/tank-door-open.ogg", volume=0.48 },
    close_sound = { filename = "__base__/sound/fight/tank-door-close.ogg", volume = 0.43 },
    rotation_speed = 0.01,
    tank_driving = false,
    weight = 750,
    inventory_size = 40,
    track_particle_triggers = movement_triggers.tank,
    guns = {"tronlaser"},
    water_reflection = car_reflection(1.2)
  },
})
    